@@ -1,6 +1,6 @@
 # test_icsdll.py
 
-# Copyright (c) 2016-2021, Christoph Gohlke
+# Copyright (c) 2016-2022, Christoph Gohlke
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,7 @@
 
 :License: BSD 3-Clause
 
-:Version: 2021.3.2
+:Version: 2022.2.6
 
 """
 
@@ -57,7 +57,7 @@ from numpy.testing import assert_array_equal, assert_allclose
 HERE = os.path.dirname(__file__) + '/'
 
 
-def test_versions(version='2021.3.2', apiversion='2021.3.2'):
+def test_versions(version='2022.2.6', apiversion='2022.2.6'):
     """Test versions match."""
     assert icsdll.__version__ == version
     assert API.VERSION == apiversion
@@ -65,66 +65,17 @@ def test_versions(version='2021.3.2', apiversion='2021.3.2'):
 
 def test_logbins():
     """Test logbins function."""
+    # fmt: off
     assert_array_equal(
         logbins(32, 32),
-        [
-            1,
-            2,
-            3,
-            4,
-            5,
-            6,
-            7,
-            8,
-            9,
-            10,
-            11,
-            13,
-            14,
-            16,
-            18,
-            20,
-            22,
-            25,
-            28,
-            32,
-        ],
+        [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 13, 14, 16, 18, 20, 22, 25, 28, 32]
     )
     assert_array_equal(
         logbins(8192, 32),
-        [
-            1,
-            2,
-            3,
-            4,
-            5,
-            7,
-            10,
-            13,
-            18,
-            24,
-            32,
-            43,
-            58,
-            78,
-            104,
-            139,
-            187,
-            250,
-            334,
-            447,
-            598,
-            800,
-            1070,
-            1432,
-            1915,
-            2561,
-            3425,
-            4580,
-            6125,
-            8192,
-        ],
+        [1, 2, 3, 4, 5, 7, 10, 13, 18, 24, 32, 43, 58, 78, 104, 139, 187, 250,
+         334, 447, 598, 800, 1070, 1432, 1915, 2561, 3425, 4580, 6125, 8192]
     )
+    # fmt: on
     with pytest.raises(icsdll.IcsError):
         logbins(2, 2)
 
@@ -133,119 +84,32 @@ def test_circle():
     """Test circle function."""
     assert_array_equal(circle(0), numpy.empty((0, 2), dtype='int64'))
     assert_array_equal(circle(1), [[1, 0], [0, 1], [-1, 0], [0, -1]])
+    # fmt: off
     assert_array_equal(
         circle(6),
-        [
-            [6, 0],
-            [6, 1],
-            [6, 2],
-            [5, 3],
-            [4, 4],
-            [3, 5],
-            [2, 6],
-            [1, 6],
-            [0, 6],
-            [-1, 6],
-            [-2, 6],
-            [-3, 5],
-            [-4, 4],
-            [-5, 3],
-            [-6, 2],
-            [-6, 1],
-            [-6, 0],
-            [-6, -1],
-            [-6, -2],
-            [-5, -3],
-            [-4, -4],
-            [-3, -5],
-            [-2, -6],
-            [-1, -6],
-            [0, -6],
-            [1, -6],
-            [2, -6],
-            [3, -5],
-            [4, -4],
-            [5, -3],
-            [6, -2],
-            [6, -1],
-        ],
+        [[6, 0], [6, 1], [6, 2], [5, 3], [4, 4], [3, 5], [2, 6], [1, 6],
+         [0, 6], [-1, 6], [-2, 6], [-3, 5], [-4, 4], [-5, 3], [-6, 2],
+         [-6, 1], [-6, 0], [-6, -1], [-6, -2], [-5, -3], [-4, -4], [-3, -5],
+         [-2, -6], [-1, -6], [0, -6], [1, -6], [2, -6], [3, -5], [4, -4],
+         [5, -3], [6, -2], [6, -1]]
     )
+    # fmt: on
 
 
 def test_radial():
     """Test radial function."""
+    # fmt: off
     assert_array_equal(
         radial(8, 4),
         numpy.array(
-            [
-                0,
-                0,
-                0,
-                1,
-                0,
-                2,
-                0,
-                3,
-                0,
-                0,
-                1,
-                1,
-                1,
-                1,
-                2,
-                2,
-                0,
-                0,
-                1,
-                0,
-                2,
-                0,
-                3,
-                0,
-                0,
-                0,
-                1,
-                -1,
-                1,
-                -1,
-                2,
-                -2,
-                0,
-                0,
-                0,
-                -1,
-                0,
-                -2,
-                0,
-                -3,
-                0,
-                0,
-                -1,
-                -1,
-                -1,
-                -1,
-                -2,
-                -2,
-                0,
-                0,
-                -1,
-                0,
-                -2,
-                0,
-                -3,
-                0,
-                0,
-                0,
-                -1,
-                1,
-                -1,
-                1,
-                -2,
-                2,
-            ],
+            [0, 0, 0, 1, 0, 2, 0, 3, 0, 0, 1, 1, 1, 1, 2, 2, 0, 0, 1, 0, 2,
+             0, 3, 0, 0, 0, 1, -1, 1, -1, 2, -2, 0, 0, 0, -1, 0, -2, 0, -3,
+             0, 0, -1, -1, -1, -1, -2, -2, 0, 0, -1, 0, -2, 0, -3, 0, 0, 0,
+             -1, 1, -1, 1, -2, 2],
             dtype='intp',
         ).reshape((8, 4, 2))[:, :, ::-1],
     )
+    # fmt: on
 
 
 def test_rfftnd_autocorrelate444():
@@ -262,34 +126,26 @@ def test_rfftnd_autocorrelate444():
     t[3:11:2, 19:15:-1, 37:49:3] = a
     b = t[3:11:2, 19:15:-1, 37:49:3]  # a view
 
+    # fmt: off
     test_out = numpy.array(
-        [
-            [
-                [0.30964979, 0.31015369, 0.31166541, 0.31015369],
-                [0.31771227, 0.31821618, 0.31972789, 0.31821618],
-                [0.34189972, 0.34240363, 0.34391534, 0.34240363],
-                [0.31771227, 0.31821618, 0.31972789, 0.31821618],
-            ],
-            [
-                [-0.07734946, -0.07684555, -0.07533384, -0.07684555],
-                [-0.06928697, -0.06878307, -0.06727135, -0.06878307],
-                [-0.04509952, -0.04459562, -0.0430839, -0.04459562],
-                [-0.06928697, -0.06878307, -0.06727135, -0.06878307],
-            ],
-            [
-                [-0.20634921, -0.2058453, -0.20433359, -0.2058453],
-                [-0.19828672, -0.19778282, -0.1962711, -0.19778282],
-                [-0.17409927, -0.17359536, -0.17208365, -0.17359536],
-                [-0.19828672, -0.19778282, -0.1962711, -0.19778282],
-            ],
-            [
-                [-0.07734946, -0.07684555, -0.07533384, -0.07684555],
-                [-0.06928697, -0.06878307, -0.06727135, -0.06878307],
-                [-0.04509952, -0.04459562, -0.0430839, -0.04459562],
-                [-0.06928697, -0.06878307, -0.06727135, -0.06878307],
-            ],
-        ]
+        [[[0.30964979, 0.31015369, 0.31166541, 0.31015369],
+          [0.31771227, 0.31821618, 0.31972789, 0.31821618],
+          [0.34189972, 0.34240363, 0.34391534, 0.34240363],
+          [0.31771227, 0.31821618, 0.31972789, 0.31821618]],
+         [[-0.07734946, -0.07684555, -0.07533384, -0.07684555],
+          [-0.06928697, -0.06878307, -0.06727135, -0.06878307],
+          [-0.04509952, -0.04459562, -0.0430839, -0.04459562],
+          [-0.06928697, -0.06878307, -0.06727135, -0.06878307]],
+         [[-0.20634921, -0.2058453, -0.20433359, -0.2058453],
+          [-0.19828672, -0.19778282, -0.1962711, -0.19778282],
+          [-0.17409927, -0.17359536, -0.17208365, -0.17359536],
+          [-0.19828672, -0.19778282, -0.1962711, -0.19778282]],
+         [[-0.07734946, -0.07684555, -0.07533384, -0.07684555],
+          [-0.06928697, -0.06878307, -0.06727135, -0.06878307],
+          [-0.04509952, -0.04459562, -0.0430839, -0.04459562],
+          [-0.06928697, -0.06878307, -0.06727135, -0.06878307]]]
     )
+    # fmt: on
 
     with rfftnd((4, 4, 4), mode=3) as fft:
         fft.autocorrelate(a, None)
@@ -675,13 +531,13 @@ def test_rfftnd_huge3d():
 
 def test_rfftnd_shapes3d():
     """Test rfft3d crosscorrelate with different shapes."""
-    shape = 32, 32, 2 ** 16
+    shape = 32, 32, 2**16
     a = numpy.random.rand(*shape)
     with timer(f'rfftnd.autocorrelate {shape}'):
         with rfftnd(shape, mode=0) as fft:
             fft.autocorrelate(a, a)
 
-    shape = 2 ** 16, 32, 32
+    shape = 2**16, 32, 32
     a = numpy.random.rand(*shape)
 
     with timer(f'rfftnd.autocorrelate {shape}'):
@@ -744,94 +600,19 @@ def test_yxt_ipcf():
             data, radius=4, nbins=32, smooth=0.7, nthreads=0
         )
 
+    # fmt: off
     assert_array_equal(
         bins,
-        [
-            1,
-            2,
-            3,
-            4,
-            5,
-            7,
-            10,
-            13,
-            18,
-            24,
-            32,
-            43,
-            58,
-            78,
-            104,
-            139,
-            187,
-            250,
-            334,
-            447,
-            598,
-            800,
-            1070,
-            1432,
-            1915,
-            2561,
-            3425,
-            4580,
-            6125,
-            8192,
-        ],
+        [1, 2, 3, 4, 5, 7, 10, 13, 18, 24, 32, 43, 58, 78, 104, 139, 187, 250,
+         334, 447, 598, 800, 1070, 1432, 1915, 2561, 3425, 4580, 6125, 8192]
     )
     assert_array_equal(
         points.flat,
-        [
-            4,
-            0,
-            4,
-            1,
-            3,
-            2,
-            3,
-            3,
-            2,
-            3,
-            1,
-            4,
-            0,
-            4,
-            -1,
-            4,
-            -2,
-            3,
-            -3,
-            3,
-            -3,
-            2,
-            -4,
-            1,
-            -4,
-            0,
-            -4,
-            -1,
-            -3,
-            -2,
-            -3,
-            -3,
-            -2,
-            -3,
-            -1,
-            -4,
-            0,
-            -4,
-            1,
-            -4,
-            2,
-            -3,
-            3,
-            -3,
-            3,
-            -2,
-            4,
-            -1,
-        ],
+        [4, 0, 4, 1, 3, 2, 3, 3, 2, 3, 1, 4, 0, 4, -1, 4, -2, 3, -3, 3, -3,
+         2, -4, 1, -4, 0, -4, -1, -3, -2, -3, -3, -2, -3, -1, -4, 0, -4, 1,
+         -4, 2, -3, 3, -3, 3, -2, 4, -1]
     )
+    # fmt: on
 
     known = numpy.fromfile(
         HERE + 'Simulation_Channel.ipcf.bin', dtype='float32'
@@ -859,235 +640,32 @@ def test_yxt_apcf():
     known = numpy.fromfile(HERE + 'Airy_Detectors.apcf.bin', dtype='float32')
     known.shape = result.shape
     assert_allclose(result, known, atol=1e-6)
+    # fmt: off
     assert_array_equal(
         bins,
-        [
-            1,
-            2,
-            3,
-            4,
-            5,
-            6,
-            7,
-            8,
-            9,
-            10,
-            11,
-            12,
-            13,
-            14,
-            15,
-            16,
-            17,
-            18,
-            19,
-            21,
-            22,
-            23,
-            25,
-            26,
-            28,
-            30,
-            32,
-            34,
-            36,
-            38,
-            40,
-            43,
-            45,
-            48,
-            51,
-            54,
-            58,
-            61,
-            65,
-            69,
-            74,
-            78,
-            83,
-            88,
-            94,
-            99,
-            106,
-            112,
-            119,
-            126,
-            134,
-            143,
-            151,
-            161,
-            171,
-            181,
-            192,
-            204,
-            217,
-            230,
-            245,
-            260,
-            276,
-            293,
-            311,
-            330,
-            350,
-            372,
-            395,
-            419,
-            445,
-            473,
-            502,
-            533,
-            566,
-            601,
-            638,
-            677,
-            719,
-            763,
-            810,
-            860,
-            913,
-            969,
-            1029,
-            1093,
-            1160,
-            1231,
-            1307,
-            1388,
-            1473,
-            1564,
-            1661,
-            1763,
-            1872,
-            1987,
-            2110,
-            2240,
-            2378,
-            2524,
-            2680,
-            2845,
-            3020,
-            3207,
-            3404,
-            3614,
-            3837,
-            4073,
-            4324,
-            4591,
-            4874,
-            5174,
-            5493,
-            5832,
-            6191,
-            6573,
-            6978,
-            7408,
-            7864,
-            8349,
-            8863,
-            9410,
-            9990,
-            10605,
-            11259,
-            11953,
-            12689,
-            13471,
-            14301,
-            15183,
-            16118,
-            17112,
-            18166,
-            19286,
-            20474,
-            21736,
-            23076,
-            24498,
-            26007,
-            27610,
-            29312,
-            31118,
-            33036,
-            35072,
-            37233,
-            39528,
-            41963,
-            44549,
-            47295,
-            50209,
-            53304,
-            56589,
-            60076,
-            63778,
-            67708,
-            71881,
-            76311,
-            81013,
-            86006,
-            91306,
-            96933,
-            102906,
-            109248,
-            115981,
-            123128,
-            130716,
-            138771,
-            147323,
-            156402,
-            166040,
-            176272,
-            187135,
-            198668,
-            210910,
-            223908,
-            237706,
-            252355,
-            267906,
-            284416,
-            301944,
-            320551,
-            340305,
-            361276,
-            383540,
-            407176,
-            432268,
-            458907,
-            487187,
-            517210,
-            549083,
-            582921,
-            618843,
-            656980,
-            697466,
-            740448,
-            786078,
-            834520,
-            885948,
-            940544,
-            998506,
-            1060039,
-            1125364,
-            1194715,
-            1268339,
-            1346501,
-            1429479,
-            1517571,
-            1611092,
-            1710376,
-            1815778,
-            1927676,
-            2046469,
-            2172583,
-            2306469,
-            2448606,
-            2599502,
-            2759696,
-            2929763,
-            3110311,
-            3301984,
-            3505470,
-            3721495,
-            3950833,
-            4194304,
-        ],
+        [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 21,
+         22, 23, 25, 26, 28, 30, 32, 34, 36, 38, 40, 43, 45, 48, 51, 54, 58,
+         61, 65, 69, 74, 78, 83, 88, 94, 99, 106, 112, 119, 126, 134, 143, 151,
+         161, 171, 181, 192, 204, 217, 230, 245, 260, 276, 293, 311, 330, 350,
+         372, 395, 419, 445, 473, 502, 533, 566, 601, 638, 677, 719, 763, 810,
+         860, 913, 969, 1029, 1093, 1160, 1231, 1307, 1388, 1473, 1564, 1661,
+         1763, 1872, 1987, 2110, 2240, 2378, 2524, 2680, 2845, 3020, 3207,
+         3404, 3614, 3837, 4073, 4324, 4591, 4874, 5174, 5493, 5832, 6191,
+         6573, 6978, 7408, 7864, 8349, 8863, 9410, 9990, 10605, 11259, 11953,
+         12689, 13471, 14301, 15183, 16118, 17112, 18166, 19286, 20474, 21736,
+         23076, 24498, 26007, 27610, 29312, 31118, 33036, 35072, 37233, 39528,
+         41963, 44549, 47295, 50209, 53304, 56589, 60076, 63778, 67708, 71881,
+         76311, 81013, 86006, 91306, 96933, 102906, 109248, 115981, 123128,
+         130716, 138771, 147323, 156402, 166040, 176272, 187135, 198668,
+         210910, 223908, 237706, 252355, 267906, 284416, 301944, 320551,
+         340305, 361276, 383540, 407176, 432268, 458907, 487187, 517210,
+         549083, 582921, 618843, 656980, 697466, 740448, 786078, 834520,
+         885948, 940544, 998506, 1060039, 1125364, 1194715, 1268339, 1346501,
+         1429479, 1517571, 1611092, 1710376, 1815778, 1927676, 2046469,
+         2172583, 2306469, 2448606, 2599502, 2759696, 2929763, 3110311,
+         3301984, 3505470, 3721495, 3950833, 4194304]
     )
+    # fmt: on
 
 
 def test_yxt_lstics():
@@ -1118,126 +696,38 @@ def test_yxt_lstics():
         bins,
         [1, 3, 6, 11, 20, 36, 67, 122, 222, 406, 741, 1351, 2463, 4492, 8192],
     )
+    # fmt: off
     assert_array_equal(
         lines,
-        [
-            [[0, 0], [1, 0], [2, 0], [3, 0], [4, 0], [5, 0], [6, 0], [7, 0]],
-            [[0, 0], [1, 0], [2, 1], [3, 1], [4, 2], [5, 2], [6, 2], [6, 3]],
-            [[0, 0], [1, 1], [1, 1], [2, 2], [3, 3], [4, 4], [4, 4], [5, 5]],
-            [[0, 0], [0, 1], [1, 2], [1, 3], [2, 4], [2, 5], [2, 6], [3, 6]],
-            [[0, 0], [0, 1], [0, 2], [0, 3], [0, 4], [0, 5], [0, 6], [0, 7]],
-            [
-                [0, 0],
-                [0, 1],
-                [-1, 2],
-                [-1, 3],
-                [-2, 4],
-                [-2, 5],
-                [-2, 6],
-                [-3, 6],
-            ],
-            [
-                [0, 0],
-                [-1, 1],
-                [-1, 1],
-                [-2, 2],
-                [-3, 3],
-                [-4, 4],
-                [-4, 4],
-                [-5, 5],
-            ],
-            [
-                [0, 0],
-                [-1, 0],
-                [-2, 1],
-                [-3, 1],
-                [-4, 2],
-                [-5, 2],
-                [-6, 2],
-                [-6, 3],
-            ],
-            [
-                [0, 0],
-                [-1, 0],
-                [-2, 0],
-                [-3, 0],
-                [-4, 0],
-                [-5, 0],
-                [-6, 0],
-                [-7, 0],
-            ],
-            [
-                [0, 0],
-                [-1, 0],
-                [-2, -1],
-                [-3, -1],
-                [-4, -2],
-                [-5, -2],
-                [-6, -2],
-                [-6, -3],
-            ],
-            [
-                [0, 0],
-                [-1, -1],
-                [-1, -1],
-                [-2, -2],
-                [-3, -3],
-                [-4, -4],
-                [-4, -4],
-                [-5, -5],
-            ],
-            [
-                [0, 0],
-                [0, -1],
-                [-1, -2],
-                [-1, -3],
-                [-2, -4],
-                [-2, -5],
-                [-2, -6],
-                [-3, -6],
-            ],
-            [
-                [0, 0],
-                [0, -1],
-                [0, -2],
-                [0, -3],
-                [0, -4],
-                [0, -5],
-                [0, -6],
-                [0, -7],
-            ],
-            [
-                [0, 0],
-                [0, -1],
-                [1, -2],
-                [1, -3],
-                [2, -4],
-                [2, -5],
-                [2, -6],
-                [3, -6],
-            ],
-            [
-                [0, 0],
-                [1, -1],
-                [1, -1],
-                [2, -2],
-                [3, -3],
-                [4, -4],
-                [4, -4],
-                [5, -5],
-            ],
-            [
-                [0, 0],
-                [1, 0],
-                [2, -1],
-                [3, -1],
-                [4, -2],
-                [5, -2],
-                [6, -2],
-                [6, -3],
-            ],
-        ],
+        [[[0, 0], [1, 0], [2, 0], [3, 0], [4, 0], [5, 0], [6, 0], [7, 0]],
+         [[0, 0], [1, 0], [2, 1], [3, 1], [4, 2], [5, 2], [6, 2], [6, 3]],
+         [[0, 0], [1, 1], [1, 1], [2, 2], [3, 3], [4, 4], [4, 4], [5, 5]],
+         [[0, 0], [0, 1], [1, 2], [1, 3], [2, 4], [2, 5], [2, 6], [3, 6]],
+         [[0, 0], [0, 1], [0, 2], [0, 3], [0, 4], [0, 5], [0, 6], [0, 7]],
+         [[0, 0], [0, 1], [-1, 2], [-1, 3],
+          [-2, 4], [-2, 5], [-2, 6], [-3, 6]],
+         [[0, 0], [-1, 1], [-1, 1], [-2, 2],
+          [-3, 3], [-4, 4], [-4, 4], [-5, 5]],
+         [[0, 0], [-1, 0], [-2, 1], [-3, 1],
+          [-4, 2], [-5, 2], [-6, 2], [-6, 3]],
+         [[0, 0], [-1, 0], [-2, 0], [-3, 0],
+          [-4, 0], [-5, 0], [-6, 0], [-7, 0]],
+         [[0, 0], [-1, 0], [-2, -1], [-3, -1],
+          [-4, -2], [-5, -2], [-6, -2], [-6, -3]],
+         [[0, 0], [-1, -1], [-1, -1], [-2, -2],
+          [-3, -3], [-4, -4], [-4, -4], [-5, -5]],
+         [[0, 0], [0, -1], [-1, -2], [-1, -3],
+          [-2, -4], [-2, -5], [-2, -6], [-3, -6]],
+         [[0, 0], [0, -1], [0, -2], [0, -3],
+          [0, -4], [0, -5], [0, -6], [0, -7]],
+         [[0, 0], [0, -1], [1, -2], [1, -3],
+          [2, -4], [2, -5], [2, -6], [3, -6]],
+         [[0, 0], [1, -1], [1, -1], [2, -2],
+          [3, -3], [4, -4], [4, -4], [5, -5]],
+         [[0, 0], [1, 0], [2, -1], [3, -1],
+          [4, -2], [5, -2], [6, -2], [6, -3]]],
     )
+    # fmt: on
 
 
 def test_yxt_imsd():
@@ -1384,18 +874,11 @@ def test_ipcf_nlsp_1dpcf():
 
     args = [0.1, 1.0, 0.3 * 0.3]
     bounds = [1e-6, 1e3, 1e-6, 1e3]
+    # fmt: off
     settings = [
-        400.0,
-        200.0,
-        1e-10,
-        1e-10,
-        1e-10,
-        1e-10,
-        1e-10,
-        1e-10,
-        1e-10,
-        0,
+        400.0, 200.0, 1e-10, 1e-10, 1e-10, 1e-10, 1e-10, 1e-10, 1e-10, 0.0
     ]
+    # fmt: on
 
     with timer('ipcf_nlsp_1dpcf'):
         x, fx, status = ipcf_nlsp_1dpcf(
